@@ -8,6 +8,7 @@ import time
 from rich.layout import Layout
 from rich.live import Live
 from rich.table import Table
+from rich.panel import Panel
 
 
 
@@ -30,52 +31,52 @@ class BalconyServiceSummarizer(BaseBalconyApp,
         service_node = balcony.get_service(service)
         resource_nodes = service_node.get_resource_nodes()
         read_only_function_count = 0
-        resource_node_names = []
+        resource_nodes = []
         for rn in resource_nodes:
-            resource_node_names.append(rn.name)
-            read_only_function_count += len(rn.operation_names)
+            operation_names = rn.get_operation_names() 
+            resource_nodes.append({
+                'name': rn.name,
+                'operation_names': operation_names
+            })
+            read_only_function_count += len(operation_names)
         return {
             'read_only_function_count':read_only_function_count,
-            'resource_node_names': resource_node_names
+            'resource_nodes': resource_nodes
         } 
        
     def get_cli_app(self, *args, **kwargs) -> typer.main.Typer:
         app = typer.Typer(no_args_is_help=True)
         
         
-        def generate_table() -> Table:
-            """Make a new table."""
-            table = Table()
-            table.add_column("ID")
-            table.add_column("Value")
-            table.add_column("Status")
-
-            for row in range(random.randint(2, 6)):
-                value = random.random() * 100
-                table.add_row(
-                    f"{row}", f"{value:3.2f}", "[red]ERROR" if value < 50 else "[green]SUCCESS"
-                )
-            return table
-
+        def kayan_yazi(_list, window=5):
+            length = len(_list)
+            until = length - window
+            for i in range(until+1):
+                yield _list[i:i+window]
+        
+        def generate_live_render(data):
+            nonlocal self
+            resource_node_names = [r.get('name') for r in data.get('resource_nodes')]
+            rn_names = data.get('resource_node_names')
+            for ky in kayan_yazi(resource_node_names):
+                layout = Layout(Panel(ky), name="main")
+                yield layout
 
 
         @app.callback(invoke_without_command=True)
         def _command(
             service: str = typer.Argument(None, show_default=False,help='AWS Service Name'),
         ):
-            data = self.get_data(service=service)
+            balcony = BalconyAWS()
+            available_services = balcony.get_available_service_node_names()
+            selected_service = random.choice(available_services)
+            data = self.get_data(service=selected_service)
 
-            # layout = Layout()
-            # layout.split_column(
-            #     Layout(name="upper"),
-            #     Layout(name="lower")
-            # )            
-            # console.print(layout)
-            # console.print(data)
-            with Live(generate_table(), refresh_per_second=4) as live:
-                for _ in range(40):
+            with Live(selected_service, refresh_per_second=2) as live:
+                for rendered in generate_live_render(data):
+                    live.update(rendered)
                     time.sleep(0.4)
-                    live.update(generate_table())
+                    
         return app
                 
     
